/*
 * Copyright 2020 Kunbus GmbH.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <MQTTClient.h>

using namespace std;

const char *ADDRESS = "tcp://192.168.178.49";
const char *TOPIC = "test";

int main(int argc, char* argv[]) {
    const char *MESSAGE_STRING = "Hello, this is a message from the RevPi";
    
    MQTTClient mqttClient;
    MQTTClient_connectOptions connectionOptions = MQTTClient_connectOptions_initializer;
    MQTTClient_message message = MQTTClient_message_initializer;
    MQTTClient_deliveryToken deliveryToken;

    MQTTClient_create(&mqttClient, ADDRESS, "RevPi", 
            MQTTCLIENT_PERSISTENCE_NONE, NULL);
    
    connectionOptions.keepAliveInterval = 20;
    connectionOptions.cleansession = 1;

    if (MQTTClient_connect(mqttClient, &connectionOptions) != MQTTCLIENT_SUCCESS) {
        printf("Failed to connect\n");
        return (-1);
    }
     
    // Necessary to avoid compiler warning, as direct conversion of a const char* to char* in ISO C++ is forbidden
    char *s = new char[strlen(MESSAGE_STRING)+1];
    strcpy(s,MESSAGE_STRING);
    
    message.payload = s;
    message.payloadlen = strlen(s);
    message.qos = 0;
    message.retained = 0;

    MQTTClient_publishMessage(mqttClient, TOPIC, &message, &deliveryToken);
    MQTTClient_disconnect(mqttClient, 5000);
    MQTTClient_destroy(&mqttClient);

    return (0);
}
